@@ -1,18 +1,16 @@
-# Copyright (c) 2013, Sascha Peilicke <saschpe@gmx.de>
+# Copyright 2013 Sascha Peilicke
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation.
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+#   http://www.apache.org/licenses/LICENSE-2.0
 #
-# You should have received a copy of the GNU General Public License
-# along with this program (see the file COPYING); if not, write to the
-# Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 import os
 import shutil
@@ -32,7 +30,7 @@ def _get_config_dirs():
     config_dirs = [
         os.path.expanduser(os.path.join("~", ".rapport")),
         os.path.join("/", "etc", "rapport"),
-        os.path.abspath("config")
+        os.path.abspath(os.path.join("rapport", "config"))
     ]
     return config_dirs
 
@@ -50,10 +48,6 @@ def find_config_files():
     return filter(bool, config_files)
 
 
-def _get_reports_dir():
-    return os.path.expanduser(os.path.join("~", ".rapport", "reports")),
-
-
 def init_user():
     """Create and populate the ~/.rapport directory tree if it's not existing.
 
@@ -80,7 +74,8 @@ def init_user():
         if rapport.config.get_int("rapport", "verbosity") >= 1:
             print "Create user configuration {0}".format(user_conf_file)
         default_config = find_config_files()
-        shutil.copyfile(default_config[0], user_conf_file)
+        default_config = os.path.abspath(os.path.join("rapport", "config", "rapport.conf"))
+        shutil.copyfile(default_config, user_conf_file)
     if not (os.stat(user_conf_file).st_mode & 0777) == 0600:
         if rapport.config.get_int("rapport", "verbosity") >= 1:
             print "Set secure file permissions for {0}".format(user_conf_file)
@@ -98,12 +93,19 @@ def load():
     return CONF
 
 
-def get(section, option):
-    return CONF.get(section, option)
+def get(section, option, default=None):
+    if CONF.has_option(section, option):
+        return CONF.get(section, option)
+    else:
+        return default
 
 
-def get_int(section, option):
-    return int(get(section, option))
+def get_int(section, option, default=None):
+    return int(get(section, option, default))
+
+
+def set(section, option, value):
+    CONF.set(section, option, str(value))
 
 
 def plugins():
